History
-------

0.2.5 (2014-03-05)
^^^^^^^^^^^^^^^^^^

* Added test REST API for anonymous user and another user
* Fixed #6 any authenticated users can change bookmarks
* Fixed #8 invalid URL of login on logout page

0.2.4 (2014-03-01)
^^^^^^^^^^^^^^^^^^

* Redirect root to /shiori/
* Add test code of routing, bookmark view, REST API
* Use django test in setup.py test
* Use tox
* Use travis-ci
* Use coverage and coverall.io

0.2.3 (2014-02-26)
^^^^^^^^^^^^^^^^^^

* Add pagination
* Remove patches of django-openid-auth why fixed at python-django-auth-openid 0.5-2

0.2.2 (2014-02-22)
^^^^^^^^^^^^^^^^^^

* Fix importing modules

0.2.1 (2014-02-16)
^^^^^^^^^^^^^^^^^^

* Remove django-notification from dependency

0.2.0 (2014-02-16)
^^^^^^^^^^^^^^^^^^

* Added feed generator
* Fixed some bugs related views

0.1.0 (2014-02-08)
^^^^^^^^^^^^^^^^^^

* First release

